summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TTableCell.php
diff options
context:
space:
mode:
authorFabio Bas <ctrlaltca@gmail.com>2015-01-25 20:04:57 +0100
committerFabio Bas <ctrlaltca@gmail.com>2015-01-25 20:04:57 +0100
commite4999b25052d1ad9400a0f9fd5289a49eea1bddc (patch)
tree50e9b819fc3326cf08e882b648f8dafc8fec3fa4 /framework/Web/UI/WebControls/TTableCell.php
parent5230f8f8a86fc1ae5d90f8c74ae65c93e197502b (diff)
More namespace changes
Changed version to 3.2.99; Attempt at fixing autoloading fixed enough namespaces to have some demos running
Diffstat (limited to 'framework/Web/UI/WebControls/TTableCell.php')
-rw-r--r--framework/Web/UI/WebControls/TTableCell.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/framework/Web/UI/WebControls/TTableCell.php b/framework/Web/UI/WebControls/TTableCell.php
index a61e1000..ede0e04c 100644
--- a/framework/Web/UI/WebControls/TTableCell.php
+++ b/framework/Web/UI/WebControls/TTableCell.php
@@ -10,6 +10,7 @@
*/
namespace Prado\Web\UI\WebControls;
+use Prado\TPropertyValue;
/**
* TTableCell class.
@@ -32,7 +33,7 @@ namespace Prado\Web\UI\WebControls;
* @package Prado\Web\UI\WebControls
* @since 3.0
*/
-class TTableCell extends TWebControl implements IDataRenderer
+class TTableCell extends \Prado\Web\UI\WebControls\TWebControl implements \Prado\IDataRenderer
{
/**
* @return string tag name for the table cell
@@ -168,7 +169,7 @@ class TTableCell extends TWebControl implements IDataRenderer
/**
* Returns the text content of the table cell.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link getText()}.
* @return string the text content of the table cell.
* @see getText
@@ -181,7 +182,7 @@ class TTableCell extends TWebControl implements IDataRenderer
/**
* Sets the text content of the table cell.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link setText()}.
* @param string the text content of the table cell.
* @see setText
@@ -168,7 +169,7 @@ class TTableCell extends TWebControl implements IDataRenderer
/**
* Returns the text content of the table cell.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link getText()}.
* @return string the text content of the table cell.
@@ -181,7 +182,7 @@ class TTableCell extends TWebControl implements IDataRenderer
/**
* Sets the text content of the table cell.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link setText()}.
* @param string the text content of the table cell.